EventModel class

Constructors

EventModel({required DateTime startTime, required DateTime endTime, Widget? childWidget, String title = '', String description = '', required String statusColor})

Properties

childWidget → Widget?
final
description → String
final
endTime → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime
final
statusColor → String
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited